@@ -3,72 +3,9 @@
  * Licensed under MIT License. See LICENSE in root directory for more information.
  */
 
-import { compile } from "path-to-regexp";
-import { apiBase } from "../index";
-import { stringify } from "querystring";
-import type { RequestInit } from "node-fetch";
-import { autoBind, bifurcateArray, isDefined } from "../../utils";
+import { autoBind, bifurcateArray } from "../../utils";
 import Joi from "joi";
 
-export type RepoHelmChartList = Record<string, RawHelmChart[]>;
-
-export interface IHelmChartDetails {
-  readme: string;
-  versions: HelmChart[];
-}
-
-const endpoint = compile(`/v2/charts/:repo?/:name?`) as (params?: {
-  repo?: string;
-  name?: string;
-}) => string;
-
-/**
- * Get a list of all helm charts from all saved helm repos
- */
-export async function listCharts(): Promise<HelmChart[]> {
-  const data = await apiBase.get<Record<string, RepoHelmChartList>>(endpoint());
-
-  return Object
-    .values(data)
-    .reduce((allCharts, repoCharts) => allCharts.concat(Object.values(repoCharts)), new Array<RawHelmChart[]>())
-    .map(([chart]) => HelmChart.create(chart, { onError: "log" }))
-    .filter(isDefined);
-}
-
-export interface GetChartDetailsOptions {
-  version?: string;
-  reqInit?: RequestInit;
-}
-
-/**
- * Get the readme and all versions of a chart
- * @param repo The repo to get from
- * @param name The name of the chart to request the data of
- * @param options.version The version of the chart's readme to get, default latest
- * @param options.reqInit A way for passing in an abort controller or other browser request options
- */
-export async function getChartDetails(repo: string, name: string, { version, reqInit }: GetChartDetailsOptions = {}): Promise<IHelmChartDetails> {
-  const path = endpoint({ repo, name });
-
-  const { readme, ...data } = await apiBase.get<IHelmChartDetails>(`${path}?${stringify({ version })}`, undefined, reqInit);
-  const versions = data.versions.map(version => HelmChart.create(version, { onError: "log" })).filter(isDefined);
-
-  return {
-    readme,
-    versions,
-  };
-}
-
-/**
- * Get chart values related to a specific repos' version of a chart
- * @param repo The repo to get from
- * @param name The name of the chart to request the data of
- * @param version The version to get the values from
- */
-export async function getChartValues(repo: string, name: string, version: string): Promise<string> {
-  return apiBase.get<string>(`/v2/charts/${repo}/${name}/values?${stringify({ version })}`);
-}
-
 export interface RawHelmChart {
   apiVersion: string;
   name: string;
