@@ -7,6 +7,7 @@ import type { PodLogsQuery } from "../../../../common/k8s-api/endpoints";
 import type { ResourceDescriptor } from "../../../../common/k8s-api/kube-api";
 import loggerInjectable from "../../../../common/logger.injectable";
 import openSaveFileDialogInjectable from "../../../utils/save-file.injectable";
+import showErrorNotificationInjectable from "../../notifications/show-error-notification.injectable";
 import callForLogsInjectable from "./call-for-logs.injectable";
 
 const downloadAllLogsInjectable = getInjectable({
@@ -16,7 +17,8 @@ const downloadAllLogsInjectable = getInjectable({
     const callForLogs = di.inject(callForLogsInjectable);
     const openSaveFileDialog = di.inject(openSaveFileDialogInjectable);
     const logger = di.inject(loggerInjectable);
-
+    const showErrorNotification = di.inject(showErrorNotificationInjectable);
+    
     return async (params: ResourceDescriptor, query: PodLogsQuery) => {
       const logs = await callForLogs(params, query).catch(error => {
         logger.error("Can't download logs: ", error);
@@ -24,6 +26,8 @@ const downloadAllLogsInjectable = getInjectable({
 
       if (logs) {
         openSaveFileDialog(`${params.name}.log`, logs, "text/plain");
+      } else {
+        showErrorNotification("No logs to download");
       }
     };
   },
