@@ -10,6 +10,7 @@ export const ResourceNames: Record<KubeResource, string> = {
   "namespaces": "Namespaces",
   "nodes": "Nodes",
   "events": "Events",
+  "leases": "Leases",
   "resourcequotas": "Resource Quotas",
   "services": "Services",
   "secrets": "Secrets",
@@ -32,6 +33,7 @@ export const ResourceNames: Record<KubeResource, string> = {
   "podsecuritypolicies": "Pod Security Policies",
   "poddisruptionbudgets": "Pod Disruption Budgets",
   "priorityclasses": "Priority Classes",
+  "runtimeclasses": "Runtime Classes",
   "limitranges": "Limit Ranges",
   "roles": "Roles",
   "rolebindings": "Role Bindings",
